=head1

Locale::CLDR::Locales::Uz::Cyrl - Package for language Uzbek

=cut

package Locale::CLDR::Locales::Uz::Cyrl;
# This file auto generated from Data\common\main\uz_Cyrl.xml
#	on Fri 29 Apr  7:31:35 pm GMT

use version;

our $VERSION = version->declare('v0.29.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Uz');
# Need to add code for Key type pattern
sub display_name_pattern {
	my ($self, $name, $region, $script, $variant) = @_;

	my $display_pattern = '{0} ({1})';
	$display_pattern =~s/\{0\}/$name/g;
	my $subtags = join '{0}, {1}', grep {$_} (
		$region,
		$script,
		$variant,
	);

	$display_pattern =~s/\{1\}/$subtags/g;
	return $display_pattern;
}

has 'display_name_language' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub { 
		 sub {
			 my %languages = (
				'ab' => 'Абхазча',
 				'af' => 'Африканча',
 				'am' => 'Амхарча',
 				'ar' => 'Арабча',
 				'as' => 'Ассамча',
 				'az' => 'Озарбайжонча',
 				'be' => 'Беларусча',
 				'bg' => 'Болгарча',
 				'bn' => 'Бенгалча',
 				'bo' => 'Тибетча',
 				'bs' => 'Боснияча',
 				'ca' => 'Каталанча',
 				'cs' => 'Чехча',
 				'cy' => 'Уэлсча',
 				'da' => 'Данияча',
 				'de' => 'Олмонча',
 				'el' => 'Грекча',
 				'en' => 'Инглизча',
 				'en_GB@alt=short' => 'Бирлашган Қироллик',
 				'eo' => 'Эсперанто',
 				'es' => 'Испанча',
 				'es_419' => 'Лотин Америка испанчаси',
 				'et' => 'Эстонча',
 				'eu' => 'Баскча',
 				'fa' => 'Форсча',
 				'fi' => 'Финча',
 				'fil' => 'Филипино',
 				'fj' => 'Фижича',
 				'fo' => 'Фарэрча',
 				'fr' => 'Французча',
 				'fy' => 'Ғарбий фризианча',
 				'ga' => 'Ирландча',
 				'gl' => 'Галицийча',
 				'gn' => 'Гуарани',
 				'gsw' => 'Швейцария немисчаси',
 				'gu' => 'Гужарати',
 				'ha' => 'Хауса',
 				'haw' => 'Гавайча',
 				'he' => 'Иброний',
 				'hi' => 'Ҳиндча',
 				'hr' => 'Хорватча',
 				'ht' => 'Гаитианча',
 				'hu' => 'Венгрча',
 				'hy' => 'Арманча',
 				'id' => 'Индонезияча',
 				'ig' => 'Игбо',
 				'is' => 'Исландча',
 				'it' => 'Италянча',
 				'ja' => 'Японча',
 				'jv' => 'Яванча',
 				'ka' => 'Грузинча',
 				'kk' => 'Қозоқча',
 				'km' => 'Хмерча',
 				'kn' => 'Каннада',
 				'ko' => 'Корейсча',
 				'ks' => 'Кашмирча',
 				'ku' => 'Курдча',
 				'ky' => 'Қирғизча',
 				'la' => 'Лотинча',
 				'lb' => 'Люксембургча',
 				'lo' => 'Лао',
 				'lt' => 'Литвача',
 				'lv' => 'Латишча',
 				'mg' => 'Малагаси',
 				'mi' => 'Маори',
 				'mk' => 'Македонча',
 				'ml' => 'Малайалам',
 				'mr' => 'Марати',
 				'ms' => 'Малайча',
 				'mt' => 'Мальтача',
 				'my' => 'Бирманча',
 				'nb' => 'Норвегча Бокмал',
 				'ne' => 'Непалча',
 				'nl' => 'Голландча',
 				'nl_BE' => 'Фламандча',
 				'nn' => 'Норвегча Нинорск',
 				'or' => 'Ория',
 				'pa' => 'Панжобча',
 				'pl' => 'Полякча',
 				'ps' => 'Пушту',
 				'pt' => 'Португалча',
 				'qu' => 'Квечуа',
 				'rm' => 'Романча',
 				'ro' => 'Руминча',
 				'ru' => 'Русча',
 				'sa' => 'Санскритча',
 				'sd' => 'Синдхи',
 				'si' => 'Синхала',
 				'sk' => 'Словакча',
 				'sl' => 'Словенча',
 				'so' => 'Сомалича',
 				'sq' => 'Албанча',
 				'sr' => 'Сербча',
 				'su' => 'Сунданча',
 				'sv' => 'Шведча',
 				'sw' => 'Суахили',
 				'ta' => 'Тамилча',
 				'te' => 'Телугу',
 				'tg' => 'Тожикча',
 				'th' => 'Тайча',
 				'ti' => 'Тигринья',
 				'tk' => 'Туркманча',
 				'to' => 'Тонгоча',
 				'tr' => 'Туркча',
 				'tt' => 'Татарча',
 				'ug' => 'Уйғурча',
 				'uk' => 'Украинча',
 				'und' => 'Номаълум тил',
 				'ur' => 'Урду',
 				'uz' => 'Ўзбек',
 				'vi' => 'Вьетнамча',
 				'wo' => 'Волофча',
 				'xh' => 'Хоса',
 				'yo' => 'Йоруба',
 				'zgh' => 'Стандарт Марокаш Тамазит',
 				'zh' => 'Хитойча',
 				'zu' => 'Зулу',
 				'zxx' => 'Тил таркиби йўқ',

			);
			if (@_) {
				return $languages{$_[0]};
			}
			return \%languages;
		}
	},
);

has 'display_name_script' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		sub {
			my %scripts = (
			'Arab' => 'Араб',
 			'Armn' => 'Арман',
 			'Beng' => 'Бенгали',
 			'Bopo' => 'Бопомофо',
 			'Brai' => 'Браилле',
 			'Cyrl' => 'Кирил',
 			'Deva' => 'Девангари',
 			'Ethi' => 'Ҳабаш',
 			'Geor' => 'Грузин',
 			'Grek' => 'Юнон',
 			'Gujr' => 'Гужарати',
 			'Guru' => 'Гурмухи',
 			'Hang' => 'Хангул',
 			'Hani' => 'Хан',
 			'Hans' => 'Соддалаштирилган',
 			'Hans@alt=stand-alone' => 'Соддалаштирилган',
 			'Hant' => 'Анъанавий',
 			'Hant@alt=stand-alone' => 'Анъанавий',
 			'Hebr' => 'Иброний',
 			'Hira' => 'Хирагана',
 			'Jpan' => 'Япон',
 			'Kana' => 'Катакана',
 			'Khmr' => 'Хмер',
 			'Knda' => 'Каннада',
 			'Kore' => 'Корейс',
 			'Laoo' => 'Лао',
 			'Latn' => 'Лотин',
 			'Mlym' => 'Малайалам',
 			'Mong' => 'Мўғулча',
 			'Mymr' => 'Мьянма',
 			'Orya' => 'Ория',
 			'Sinh' => 'Синхала',
 			'Taml' => 'Тамил',
 			'Telu' => 'Телугу',
 			'Thaa' => 'Таана',
 			'Thai' => 'Тай',
 			'Tibt' => 'Тибет',
 			'Zsym' => 'Рамзлар',
 			'Zxxx' => 'Ёзилмаган',
 			'Zyyy' => 'Умумий',
 			'Zzzz' => 'Номаълум шрифт',

			);
			if ( @_ ) {
				return $scripts{$_[0]};
			}
			return \%scripts;
		}
	}
);

has 'display_name_region' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub { 
		{
			'001' => 'Дунё',
 			'002' => 'Африка',
 			'003' => 'Шимолий Америка',
 			'005' => 'Жанубий Америка',
 			'009' => 'Океания',
 			'011' => 'Ғарбий Африка',
 			'013' => 'Марказий Америка',
 			'014' => 'Шарқий Африка',
 			'015' => 'Шимолий Африка',
 			'017' => 'Марказий Африка',
 			'018' => 'Жануби-Африка',
 			'019' => 'Америка',
 			'021' => 'Шимоли-Америка',
 			'029' => 'Кариб ҳавзаси',
 			'030' => 'Шарқий Осиё',
 			'034' => 'Жанубий Осиё',
 			'035' => 'Жанубий-Шарқий Осиё',
 			'039' => 'Жанубий Европа',
 			'053' => 'Австралазия',
 			'054' => 'Меланезия',
 			'057' => 'Микронезия минтақаси',
 			'061' => 'Полинезия',
 			'142' => 'Осиё',
 			'143' => 'Марказий Осиё',
 			'145' => 'Ғарбий Осиё',
 			'150' => 'Европа',
 			'151' => 'Шарқий Европа',
 			'154' => 'Шимолий Европа',
 			'155' => 'Ғарбий Европа',
 			'419' => 'Лотин Америкаси',
 			'AC' => 'Вознесение ороли',
 			'AD' => 'Андорра',
 			'AE' => 'Бирлашган Араб Амирликлари',
 			'AF' => 'Афғонистон',
 			'AG' => 'Антигуа ва Барбадос',
 			'AI' => 'Ангила',
 			'AL' => 'Албания',
 			'AM' => 'Арманистон',
 			'AO' => 'Ангола',
 			'AQ' => 'Антарктика',
 			'AR' => 'Аргентина',
 			'AS' => 'Америка Самоаси',
 			'AT' => 'Австрия',
 			'AU' => 'Австралия',
 			'AW' => 'Аруба',
 			'AX' => 'Аланд ороллари',
 			'AZ' => 'Озарбайжон',
 			'BA' => 'Босния ва Герцеговина',
 			'BB' => 'Барбадос',
 			'BD' => 'Бангладеш',
 			'BE' => 'Бельгия',
 			'BF' => 'Буркина-Фасо',
 			'BG' => 'Болгария',
 			'BH' => 'Баҳрайн',
 			'BI' => 'Бурунди',
 			'BJ' => 'Бенин',
 			'BL' => 'Муқаддас Варфаломей',
 			'BM' => 'Бермуда',
 			'BN' => 'Бруней',
 			'BO' => 'Боливия',
 			'BQ' => 'Кариб Нидерландияси',
 			'BR' => 'Бразилия',
 			'BS' => 'Багама ороллари',
 			'BT' => 'Бутан',
 			'BV' => 'Бувет ороли',
 			'BW' => 'Ботсванна',
 			'BY' => 'Белорусия',
 			'BZ' => 'Белиз',
 			'CA' => 'Канада',
 			'CC' => 'Кокос (Килинг) ороллари',
 			'CD' => 'Конго-Киншаса',
 			'CD@alt=variant' => 'Конго (КДР)',
 			'CF' => 'Марказий Африка Республикаси',
 			'CG' => 'Конго Браззавиль',
 			'CG@alt=variant' => 'Конго (Республика)',
 			'CH' => 'Швейцария',
 			'CI' => 'Кот-д-Ивуар',
 			'CI@alt=variant' => 'Фил Суяги Қирғоғи',
 			'CK' => 'Кук ороллари',
 			'CL' => 'Чили',
 			'CM' => 'Камерун',
 			'CN' => 'Хитой',
 			'CO' => 'Колумбия',
 			'CP' => 'Клиппертон ороли',
 			'CR' => 'Коста-Рика',
 			'CU' => 'Куба',
 			'CV' => 'Кабо-Верде',
 			'CW' => 'Курасао',
 			'CX' => 'Рождество ороли',
 			'CY' => 'Кипр',
 			'CZ' => 'Чехия Республикаси',
 			'DE' => 'Олмония',
 			'DG' => 'Диего Гарсия',
 			'DJ' => 'Джибути',
 			'DK' => 'Дания',
 			'DM' => 'Доминика',
 			'DO' => 'Доминикан Республикаси',
 			'DZ' => 'Жазоир',
 			'EA' => 'Сейта ва Мелилла',
 			'EC' => 'Эквадор',
 			'EE' => 'Эстония',
 			'EG' => 'Миср',
 			'EH' => 'Ғарбий Саҳрои Кабир',
 			'ER' => 'Эритрея',
 			'ES' => 'Испания',
 			'ET' => 'Эфиопия',
 			'EU' => 'Европа Иттифоқи',
 			'FI' => 'Финляндия',
 			'FJ' => 'Фижи ороллари',
 			'FK' => 'Фолькленд ороллари',
 			'FK@alt=variant' => 'Фолькленд ороллари (Мальвин ороллари)',
 			'FM' => 'Микронезия',
 			'FO' => 'Фарер ороллари',
 			'FR' => 'Франция',
 			'GA' => 'Габон',
 			'GB' => 'Бирлашган Қироллик',
 			'GB@alt=short' => 'Бирлашган Қироллик',
 			'GD' => 'Гренада',
 			'GE' => 'Грузия',
 			'GF' => 'Француз Гвианаси',
 			'GG' => 'Гернси',
 			'GH' => 'Гана',
 			'GI' => 'Гибралтар',
 			'GL' => 'Гренландия',
 			'GM' => 'Гамбия',
 			'GN' => 'Гвинея',
 			'GP' => 'Гваделупе',
 			'GQ' => 'Экваториал Гвинея',
 			'GR' => 'Греция',
 			'GS' => 'Жанубий Джорджия ва Жанубий Сендвич ороллари',
 			'GT' => 'Гватемала',
 			'GU' => 'Гуам',
 			'GW' => 'Гвинея-Бисау',
 			'GY' => 'Гаяна',
 			'HK' => 'Гонконг Хитой ММҲ',
 			'HK@alt=short' => 'Гонконг',
 			'HM' => 'Герд ороли ва МакДоналд ороллари',
 			'HN' => 'Гондурас',
 			'HR' => 'Хорватия',
 			'HT' => 'Гаити',
 			'HU' => 'Венгрия',
 			'IC' => 'Канар ороллари',
 			'ID' => 'Индонезия',
 			'IE' => 'Ирландия',
 			'IL' => 'Исроил',
 			'IM' => 'Мэн ороли',
 			'IN' => 'Ҳиндистон',
 			'IO' => 'Британия Ҳинд океани ҳудуди',
 			'IQ' => 'Ироқ',
 			'IR' => 'Эрон',
 			'IS' => 'Исландия',
 			'IT' => 'Италия',
 			'JE' => 'Джерси',
 			'JM' => 'Ямайка',
 			'JO' => 'Иордания',
 			'JP' => 'Япония',
 			'KE' => 'Кения',
 			'KG' => 'Қирғизистон',
 			'KH' => 'Камбоджа',
 			'KI' => 'Кирибати',
 			'KM' => 'Комор ороллари',
 			'KN' => 'Сент-Китс ва Невис',
 			'KP' => 'Шимолий Корея',
 			'KR' => 'Жанубий Корея',
 			'KW' => 'Кувайт',
 			'KY' => 'Кайман ороллари',
 			'KZ' => 'Қозоғистон',
 			'LA' => 'Лаос',
 			'LB' => 'Ливан',
 			'LC' => 'Сент-Люсия',
 			'LI' => 'Лихтенштейн',
 			'LK' => 'Шри-Ланка',
 			'LR' => 'Либерия',
 			'LS' => 'Лесото',
 			'LT' => 'Литва',
 			'LU' => 'Люксембург',
 			'LV' => 'Латвия',
 			'LY' => 'Ливия',
 			'MA' => 'Марокаш',
 			'MC' => 'Монако',
 			'MD' => 'Молдова',
 			'ME' => 'Черногория',
 			'MF' => 'Сент-Мартин',
 			'MG' => 'Мадагаскар',
 			'MH' => 'Маршал ороллари',
 			'MK' => 'Македония',
 			'MK@alt=variant' => 'Македония (СЮР)',
 			'ML' => 'Мали',
 			'MM' => 'Мьянма (Бирма)',
 			'MN' => 'Муғулистон',
 			'MO' => 'Макао Хитой ММҲ',
 			'MO@alt=short' => 'Макао',
 			'MP' => 'Шимолий Марианна ороллари',
 			'MQ' => 'Мартиника',
 			'MR' => 'Мавритания',
 			'MS' => 'Монтсеррат',
 			'MT' => 'Мальта',
 			'MU' => 'Маврикий',
 			'MV' => 'Мальдив ороллари',
 			'MW' => 'Малави',
 			'MX' => 'Мексика',
 			'MY' => 'Малайзия',
 			'MZ' => 'Мозамбик',
 			'NA' => 'Намибия',
 			'NC' => 'Янги Каледония',
 			'NE' => 'Нигер',
 			'NF' => 'Норфолк ороллари',
 			'NG' => 'Нигерия',
 			'NI' => 'Никарагуа',
 			'NL' => 'Нидерландия',
 			'NO' => 'Норвегия',
 			'NP' => 'Непал',
 			'NR' => 'Науру',
 			'NU' => 'Ниуе',
 			'NZ' => 'Янги Зеландия',
 			'OM' => 'Уммон',
 			'PA' => 'Панама',
 			'PE' => 'Перу',
 			'PF' => 'Француз Полинезияси',
 			'PG' => 'Папуа Янги Гвинея',
 			'PH' => 'Филиппин',
 			'PK' => 'Покистон',
 			'PL' => 'Польша',
 			'PM' => 'Сент-Пьер ва Микелон',
 			'PN' => 'Питкарин ороллари',
 			'PR' => 'Пуэрто-Рико',
 			'PS' => 'Фаластин ҳудуди',
 			'PS@alt=short' => 'Фаластина',
 			'PT' => 'Португалия',
 			'PW' => 'Палау',
 			'PY' => 'Парагвай',
 			'QA' => 'Қатар',
 			'QO' => 'Ёндош Океания',
 			'RE' => 'Реюньон',
 			'RO' => 'Руминия',
 			'RS' => 'Сербия',
 			'RU' => 'Россия',
 			'RW' => 'Руанда',
 			'SA' => 'Саудия Арабистони',
 			'SB' => 'Соломон ороллари',
 			'SC' => 'Сейшел ороллари',
 			'SD' => 'Судан',
 			'SE' => 'Швеция',
 			'SG' => 'Сингапур',
 			'SH' => 'Муқаддас Елена ороллари',
 			'SI' => 'Словения',
 			'SJ' => 'Савльбард ва Жан Маен',
 			'SK' => 'Словакия',
 			'SL' => 'Сьерра-Леоне',
 			'SM' => 'Сан-Марино',
 			'SN' => 'Сенегал',
 			'SO' => 'Сомали',
 			'SR' => 'Суринам',
 			'SS' => 'Жанубий Судан',
 			'ST' => 'Сан-Томе ва Принсипи',
 			'SV' => 'Эль-Сальвадор',
 			'SX' => 'Синт-Маартен',
 			'SY' => 'Сурия',
 			'SZ' => 'Свазиленд',
 			'TA' => 'Тристан де Куна',
 			'TC' => 'Туркс ва Кайкос ороллари',
 			'TD' => 'Чад',
 			'TF' => 'Франция жанубий худудлари',
 			'TG' => 'Того',
 			'TH' => 'Тайланд',
 			'TJ' => 'Тожикистон',
 			'TK' => 'Токелау',
 			'TL' => 'Шарқий-Тимор',
 			'TL@alt=variant' => 'Шарқий Тимор',
 			'TM' => 'Туркманистон',
 			'TN' => 'Тунис',
 			'TO' => 'Тонга',
 			'TR' => 'Туркия',
 			'TT' => 'Тринидад ва Тобаго',
 			'TV' => 'Тувалу',
 			'TW' => 'Тайван',
 			'TZ' => 'Танзания',
 			'UA' => 'Украина',
 			'UG' => 'Уганда',
 			'UM' => 'АҚШ ёндош ороллари',
 			'US' => 'Қўшма Штатлар',
 			'US@alt=short' => 'АКШ',
 			'UY' => 'Уругвай',
 			'UZ' => 'Ўзбекистон',
 			'VA' => 'Ватикан',
 			'VC' => 'Сент-Винсент ва Гренадин',
 			'VE' => 'Венесуэла',
 			'VG' => 'Британия Вирджиния ороллари',
 			'VI' => 'АҚШ Вирджиния ороллари',
 			'VN' => 'Вьетнам',
 			'VU' => 'Вануату',
 			'WF' => 'Уэллис ва Футуна',
 			'WS' => 'Самоа',
 			'XK' => 'Косово',
 			'YE' => 'Яман',
 			'YT' => 'Майотта',
 			'ZA' => 'Жанубий Африка',
 			'ZM' => 'Замбия',
 			'ZW' => 'Зимбабве',
 			'ZZ' => 'Номаълум минтақа',

		}
	},
);

has 'display_name_key' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub { 
		{
			'calendar' => 'Календарь',
 			'collation' => 'Саралаш тартиби',
 			'currency' => 'Валюта',
 			'numbers' => 'Рақамлар',

		}
	},
);

has 'display_name_type' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[Str]],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => {
 				'gregorian' => q{Григориан календари},
 			},
 			'collation' => {
 				'ducet' => q{Сукут бўйича саралаш тартиби},
 				'search' => q{Умумий қидириш},
 				'standard' => q{Стандарт саралаш тартиби},
 			},
 			'numbers' => {
 				'arab' => q{Араб-ҳинд рақамлари},
 				'arabext' => q{Кенгайтирилган араб-ҳинд рақамлари},
 				'armn' => q{Арман сонлари},
 				'armnlow' => q{Арман кичик сонлари},
 				'beng' => q{Бенгали рақамлари},
 				'deva' => q{Деванагари рақамлари},
 				'ethi' => q{Ҳабаш сонлари},
 				'fullwide' => q{Тўлиқ кенгликдаги рақамлар},
 				'geor' => q{Грузин сонлари},
 				'grek' => q{Грек сонлари},
 				'greklow' => q{Грек кичик сонлари},
 				'gujr' => q{Гужарати рақамлари},
 				'guru' => q{Гурмухи рақамлари},
 				'hanidec' => q{Хитой ўнлик сонлари},
 				'hans' => q{Соддалаштирилган Хитой сонлари},
 				'hansfin' => q{Соддалаштирилган Хитой молия сонлари},
 				'hant' => q{Анъанавий Хитой сонлари},
 				'hantfin' => q{Анъанавий Хитой молия сонлари},
 				'hebr' => q{Иброний сонлари},
 				'jpan' => q{Япония сонлари},
 				'jpanfin' => q{Япония молия сонлари},
 				'khmr' => q{Хмер рақамлари},
 				'knda' => q{Каннада рақамлари},
 				'laoo' => q{Лао рақамлари},
 				'latn' => q{Ғарб рақамлари},
 				'mlym' => q{Малайалам рақамлари},
 				'mymr' => q{Мьянма рақамлари},
 				'orya' => q{Ория рақамлари},
 				'roman' => q{Рим сонлари},
 				'romanlow' => q{Рим кичик сонлари},
 				'taml' => q{Анъанавий Тамил сонлари},
 				'tamldec' => q{Тамил рақамлари},
 				'telu' => q{Телугу рақамлари},
 				'thai' => q{Тай рақамлари},
 				'tibt' => q{Тибет рақамлари},
 			},

		}
	},
);

has 'display_name_measurement_system' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub { 
		{
			'metric' => q{Metric},
 			'UK' => q{UK},
 			'US' => q{US},

		}
	},
);

has 'display_name_code_patterns' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub { 
		{
			'language' => 'Тил: {0}',
 			'script' => '{0}',
 			'region' => '{0}',

		}
	},
);

has 'characters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> $^V ge v5.18.0
	? eval <<'EOT'
	sub {
		no warnings 'experimental::regex_sets';
		return {
			auxiliary => qr{(?^u:[ц щ ы ь])},
			index => ['А', 'Б', 'В', 'Г', 'Ғ', 'Д', 'Е', 'Ж', 'З', 'И', 'Й', 'К', 'Қ', 'Л', 'М', 'Н', 'О', 'П', 'Р', 'С', 'Т', 'У', 'Ў', 'Ф', 'Х', 'Ҳ', 'Ч', 'Ш', 'Ъ', 'Э', 'Ю', 'Я'],
			main => qr{(?^u:[а б в г ғ д е ё ж з и й к қ л м н о п р с т у ў ф х ҳ ч ш ъ э ю я])},
		};
	},
EOT
: sub {
		return { index => ['А', 'Б', 'В', 'Г', 'Ғ', 'Д', 'Е', 'Ж', 'З', 'И', 'Й', 'К', 'Қ', 'Л', 'М', 'Н', 'О', 'П', 'Р', 'С', 'Т', 'У', 'Ў', 'Ф', 'Х', 'Ҳ', 'Ч', 'Ш', 'Ъ', 'Э', 'Ю', 'Я'], };
},
);


has 'ellipsis' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub {
		return {
			'final' => '{0}…',
			'initial' => '…{0}',
			'medial' => '{0}…{1}',
			'word-final' => '{0} …',
			'word-initial' => '… {0}',
			'word-medial' => '{0} … {1}',
		};
	},
);

has 'more_information' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{?},
);

has 'quote_start' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{“},
);

has 'quote_end' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{”},
);

has 'alternate_quote_start' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{‘},
);

has 'alternate_quote_end' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{’},
);

has 'duration_units' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub { {
				hm => 'h:mm',
				hms => 'h:mm:ss',
				ms => 'm:ss',
			} }
);

has 'units' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[HashRef[Str]]],
	init_arg	=> undef,
	default		=> sub { {
				'long' => {
					'acre' => {
						'name' => q(ac),
						'one' => q({0} ac),
						'other' => q({0} ac),
					},
					'arc-minute' => {
						'name' => q(′),
						'one' => q({0}′),
						'other' => q({0}′),
					},
					'arc-second' => {
						'name' => q(″),
						'one' => q({0}″),
						'other' => q({0}″),
					},
					'celsius' => {
						'name' => q(°C),
						'one' => q({0}°C),
						'other' => q({0}°C),
					},
					'centimeter' => {
						'name' => q(см),
						'one' => q({0} см),
						'other' => q({0} см),
					},
					'cubic-kilometer' => {
						'name' => q(km³),
						'one' => q({0} km³),
						'other' => q({0} km³),
					},
					'cubic-mile' => {
						'name' => q(mi³),
						'one' => q({0} mi³),
						'other' => q({0} mi³),
					},
					'day' => {
						'name' => q(кун),
						'one' => q({0} кун),
						'other' => q({0} кун),
					},
					'degree' => {
						'name' => q(°),
						'one' => q({0}°),
						'other' => q({0}°),
					},
					'fahrenheit' => {
						'name' => q(°F),
						'one' => q({0}°F),
						'other' => q({0}°F),
					},
					'foot' => {
						'name' => q(фут),
						'one' => q({0} фут),
						'other' => q({0} фут),
					},
					'g-force' => {
						'name' => q(G),
						'one' => q({0} G),
						'other' => q({0} G),
					},
					'gram' => {
						'name' => q(г),
						'one' => q({0} г),
						'other' => q({0} г),
					},
					'hectare' => {
						'name' => q(ha),
						'one' => q({0} ha),
						'other' => q({0} ha),
					},
					'hectopascal' => {
						'name' => q(hPa),
						'one' => q({0} hPa),
						'other' => q({0} hPa),
					},
					'horsepower' => {
						'name' => q(hp),
						'one' => q({0} hp),
						'other' => q({0} hp),
					},
					'hour' => {
						'name' => q(соат),
						'one' => q({0} соат),
						'other' => q({0} соат),
					},
					'inch' => {
						'name' => q(дюйм),
						'one' => q({0} дюйм),
						'other' => q({0} дюйм),
					},
					'inch-hg' => {
						'name' => q(inHg),
						'one' => q({0} inHg),
						'other' => q({0} inHg),
					},
					'kilogram' => {
						'name' => q(кг),
						'one' => q({0} кг),
						'other' => q({0} кг),
					},
					'kilometer' => {
						'name' => q(км),
						'one' => q({0} км),
						'other' => q({0} км),
					},
					'kilometer-per-hour' => {
						'name' => q(km/h),
						'one' => q({0} km/h),
						'other' => q({0} km/h),
					},
					'kilowatt' => {
						'name' => q(kW),
						'one' => q({0} kW),
						'other' => q({0} kW),
					},
					'light-year' => {
						'name' => q(ё.й.),
						'one' => q({0} ё.й.),
						'other' => q({0} ё.й.),
					},
					'liter' => {
						'name' => q(l),
						'one' => q({0} l),
						'other' => q({0} l),
					},
					'meter' => {
						'name' => q(м),
						'one' => q({0} м),
						'other' => q({0} м),
					},
					'meter-per-second' => {
						'name' => q(m/s),
						'one' => q({0} m/s),
						'other' => q({0} m/s),
					},
					'mile' => {
						'name' => q(миля),
						'one' => q({0} миля),
						'other' => q({0} миля),
					},
					'mile-per-hour' => {
						'name' => q(mi/h),
						'one' => q({0} mi/h),
						'other' => q({0} mi/h),
					},
					'millibar' => {
						'name' => q(mbar),
						'one' => q({0} mbar),
						'other' => q({0} mbar),
					},
					'millimeter' => {
						'name' => q(мм),
						'one' => q({0} мм),
						'other' => q({0} мм),
					},
					'millisecond' => {
						'name' => q(миллисония),
						'one' => q({0} миллисония),
						'other' => q({0} миллисония),
					},
					'minute' => {
						'name' => q(дақиқа),
						'one' => q({0} дақиқа),
						'other' => q({0} дақиқа),
					},
					'month' => {
						'name' => q(ой),
						'one' => q({0} ой),
						'other' => q({0} ой),
					},
					'ounce' => {
						'name' => q(унция),
						'one' => q({0} унция),
						'other' => q({0} унция),
					},
					'per' => {
						'1' => q({0}/{1}),
					},
					'picometer' => {
						'name' => q(пм),
						'one' => q({0} пм),
						'other' => q({0} пм),
					},
					'pound' => {
						'name' => q(фунт),
						'one' => q({0} фунт),
						'other' => q({0} фунт),
					},
					'second' => {
						'name' => q(сония),
						'one' => q({0} сония),
						'other' => q({0} сония),
					},
					'square-foot' => {
						'name' => q(ft²),
						'one' => q({0} ft²),
						'other' => q({0} ft²),
					},
					'square-kilometer' => {
						'name' => q(km²),
						'one' => q({0} km²),
						'other' => q({0} km²),
					},
					'square-meter' => {
						'name' => q(m²),
						'one' => q({0} m²),
						'other' => q({0} m²),
					},
					'square-mile' => {
						'name' => q(mi²),
						'one' => q({0} mi²),
						'other' => q({0} mi²),
					},
					'watt' => {
						'name' => q(W),
						'one' => q({0} W),
						'other' => q({0} W),
					},
					'week' => {
						'name' => q(ҳафта),
						'one' => q({0} ҳафта),
						'other' => q({0} ҳафта),
					},
					'yard' => {
						'name' => q(ярд),
						'one' => q({0} ярд),
						'other' => q({0} ярд),
					},
					'year' => {
						'name' => q(йил),
						'one' => q({0} йил),
						'other' => q({0} йил),
					},
				},
				'narrow' => {
					'acre' => {
						'one' => q({0} ac),
						'other' => q({0} ac),
					},
					'arc-minute' => {
						'one' => q({0}′),
						'other' => q({0}′),
					},
					'arc-second' => {
						'one' => q({0}″),
						'other' => q({0}″),
					},
					'celsius' => {
						'one' => q({0}°),
						'other' => q({0}°),
					},
					'centimeter' => {
						'one' => q({0} см),
						'other' => q({0} см),
					},
					'cubic-kilometer' => {
						'one' => q({0} km³),
						'other' => q({0} km³),
					},
					'cubic-mile' => {
						'one' => q({0} mi³),
						'other' => q({0} mi³),
					},
					'day' => {
						'one' => q({0} к),
						'other' => q({0} к),
					},
					'degree' => {
						'one' => q({0}°),
						'other' => q({0}°),
					},
					'fahrenheit' => {
						'one' => q({0}°F),
						'other' => q({0}°F),
					},
					'foot' => {
						'one' => q({0} фут),
						'other' => q({0} фут),
					},
					'g-force' => {
						'one' => q({0} G),
						'other' => q({0} G),
					},
					'gram' => {
						'one' => q({0} г),
						'other' => q({0} г),
					},
					'hectare' => {
						'one' => q({0} ha),
						'other' => q({0} ha),
					},
					'hectopascal' => {
						'one' => q({0} hPa),
						'other' => q({0} hPa),
					},
					'horsepower' => {
						'one' => q({0} hp),
						'other' => q({0} hp),
					},
					'hour' => {
						'one' => q({0} с),
						'other' => q({0} с),
					},
					'inch' => {
						'one' => q({0} дюйм),
						'other' => q({0} дюйм),
					},
					'inch-hg' => {
						'one' => q({0} inHg),
						'other' => q({0} inHg),
					},
					'kilogram' => {
						'one' => q({0} кг),
						'other' => q({0} кг),
					},
					'kilometer' => {
						'one' => q({0} км),
						'other' => q({0} км),
					},
					'kilometer-per-hour' => {
						'one' => q({0} km/h),
						'other' => q({0} km/h),
					},
					'kilowatt' => {
						'one' => q({0} kW),
						'other' => q({0} kW),
					},
					'light-year' => {
						'one' => q({0} ё.й.),
						'other' => q({0} ё.й.),
					},
					'liter' => {
						'one' => q({0} l),
						'other' => q({0} l),
					},
					'meter' => {
						'one' => q({0} м),
						'other' => q({0} м),
					},
					'meter-per-second' => {
						'one' => q({0} m/s),
						'other' => q({0} m/s),
					},
					'mile' => {
						'one' => q({0} миля),
						'other' => q({0} миля),
					},
					'mile-per-hour' => {
						'one' => q({0} mi/h),
						'other' => q({0} mi/h),
					},
					'millibar' => {
						'one' => q({0} mbar),
						'other' => q({0} mbar),
					},
					'millimeter' => {
						'one' => q({0} мм),
						'other' => q({0} мм),
					},
					'millisecond' => {
						'one' => q({0} мс),
						'other' => q({0} мс),
					},
					'minute' => {
						'one' => q({0} дақ),
						'other' => q({0} дақ),
					},
					'month' => {
						'one' => q({0} ой),
						'other' => q({0} ой),
					},
					'ounce' => {
						'one' => q({0} унция),
						'other' => q({0} унция),
					},
					'per' => {
						'1' => q({0}/{1}),
					},
					'picometer' => {
						'one' => q({0} пм),
						'other' => q({0} пм),
					},
					'pound' => {
						'one' => q({0} фунт),
						'other' => q({0} фунт),
					},
					'second' => {
						'one' => q({0} сон),
						'other' => q({0} сон),
					},
					'square-foot' => {
						'one' => q({0} ft²),
						'other' => q({0} ft²),
					},
					'square-kilometer' => {
						'one' => q({0} km²),
						'other' => q({0} km²),
					},
					'square-meter' => {
						'one' => q({0} m²),
						'other' => q({0} m²),
					},
					'square-mile' => {
						'one' => q({0} mi²),
						'other' => q({0} mi²),
					},
					'watt' => {
						'one' => q({0} W),
						'other' => q({0} W),
					},
					'week' => {
						'one' => q({0} ҳафт),
						'other' => q({0} ҳафт),
					},
					'yard' => {
						'one' => q({0} ярд),
						'other' => q({0} ярд),
					},
					'year' => {
						'one' => q({0} й),
						'other' => q({0} й),
					},
				},
				'short' => {
					'acre' => {
						'name' => q(ac),
						'one' => q({0} ac),
						'other' => q({0} ac),
					},
					'arc-minute' => {
						'name' => q(′),
						'one' => q({0}′),
						'other' => q({0}′),
					},
					'arc-second' => {
						'name' => q(″),
						'one' => q({0}″),
						'other' => q({0}″),
					},
					'celsius' => {
						'name' => q(°C),
						'one' => q({0}°C),
						'other' => q({0}°C),
					},
					'centimeter' => {
						'name' => q(см),
						'one' => q({0} см),
						'other' => q({0} см),
					},
					'cubic-kilometer' => {
						'name' => q(km³),
						'one' => q({0} km³),
						'other' => q({0} km³),
					},
					'cubic-mile' => {
						'name' => q(mi³),
						'one' => q({0} mi³),
						'other' => q({0} mi³),
					},
					'day' => {
						'name' => q(кун),
						'one' => q({0} кун),
						'other' => q({0} кун),
					},
					'degree' => {
						'name' => q(°),
						'one' => q({0}°),
						'other' => q({0}°),
					},
					'fahrenheit' => {
						'name' => q(°F),
						'one' => q({0}°F),
						'other' => q({0}°F),
					},
					'foot' => {
						'name' => q(фут),
						'one' => q({0} фут),
						'other' => q({0} фут),
					},
					'g-force' => {
						'name' => q(G),
						'one' => q({0} G),
						'other' => q({0} G),
					},
					'gram' => {
						'name' => q(г),
						'one' => q({0} г),
						'other' => q({0} г),
					},
					'hectare' => {
						'name' => q(ha),
						'one' => q({0} ha),
						'other' => q({0} ha),
					},
					'hectopascal' => {
						'name' => q(hPa),
						'one' => q({0} hPa),
						'other' => q({0} hPa),
					},
					'horsepower' => {
						'name' => q(hp),
						'one' => q({0} hp),
						'other' => q({0} hp),
					},
					'hour' => {
						'name' => q(соат),
						'one' => q({0} соат),
						'other' => q({0} соат),
					},
					'inch' => {
						'name' => q(дюйм),
						'one' => q({0} дюйм),
						'other' => q({0} дюйм),
					},
					'inch-hg' => {
						'name' => q(inHg),
						'one' => q({0} inHg),
						'other' => q({0} inHg),
					},
					'kilogram' => {
						'name' => q(кг),
						'one' => q({0} кг),
						'other' => q({0} кг),
					},
					'kilometer' => {
						'name' => q(км),
						'one' => q({0} км),
						'other' => q({0} км),
					},
					'kilometer-per-hour' => {
						'name' => q(km/h),
						'one' => q({0} km/h),
						'other' => q({0} km/h),
					},
					'kilowatt' => {
						'name' => q(kW),
						'one' => q({0} kW),
						'other' => q({0} kW),
					},
					'light-year' => {
						'name' => q(ё.й.),
						'one' => q({0} ё.й.),
						'other' => q({0} ё.й.),
					},
					'liter' => {
						'name' => q(l),
						'one' => q({0} l),
						'other' => q({0} l),
					},
					'meter' => {
						'name' => q(м),
						'one' => q({0} м),
						'other' => q({0} м),
					},
					'meter-per-second' => {
						'name' => q(m/s),
						'one' => q({0} m/s),
						'other' => q({0} m/s),
					},
					'mile' => {
						'name' => q(миля),
						'one' => q({0} миля),
						'other' => q({0} миля),
					},
					'mile-per-hour' => {
						'name' => q(mi/h),
						'one' => q({0} mi/h),
						'other' => q({0} mi/h),
					},
					'millibar' => {
						'name' => q(mbar),
						'one' => q({0} mbar),
						'other' => q({0} mbar),
					},
					'millimeter' => {
						'name' => q(мм),
						'one' => q({0} мм),
						'other' => q({0} мм),
					},
					'millisecond' => {
						'name' => q(миллисония),
						'one' => q({0} мс),
						'other' => q({0} мс),
					},
					'minute' => {
						'name' => q(дақиқа),
						'one' => q({0} дақ),
						'other' => q({0} дақ),
					},
					'month' => {
						'name' => q(ой),
						'one' => q({0} ой),
						'other' => q({0} ой),
					},
					'ounce' => {
						'name' => q(унция),
						'one' => q({0} унция),
						'other' => q({0} унция),
					},
					'per' => {
						'1' => q({0}/{1}),
					},
					'picometer' => {
						'name' => q(пм),
						'one' => q({0} пм),
						'other' => q({0} пм),
					},
					'pound' => {
						'name' => q(фунт),
						'one' => q({0} фунт),
						'other' => q({0} фунт),
					},
					'second' => {
						'name' => q(сония),
						'one' => q({0} сония),
						'other' => q({0} сония),
					},
					'square-foot' => {
						'name' => q(ft²),
						'one' => q({0} ft²),
						'other' => q({0} ft²),
					},
					'square-kilometer' => {
						'name' => q(km²),
						'one' => q({0} km²),
						'other' => q({0} km²),
					},
					'square-meter' => {
						'name' => q(m²),
						'one' => q({0} m²),
						'other' => q({0} m²),
					},
					'square-mile' => {
						'name' => q(mi²),
						'one' => q({0} mi²),
						'other' => q({0} mi²),
					},
					'watt' => {
						'name' => q(W),
						'one' => q({0} W),
						'other' => q({0} W),
					},
					'week' => {
						'name' => q(ҳафта),
						'one' => q({0} ҳафт),
						'other' => q({0} ҳафт),
					},
					'yard' => {
						'name' => q(ярд),
						'one' => q({0} ярд),
						'other' => q({0} ярд),
					},
					'year' => {
						'name' => q(йил),
						'one' => q({0} й),
						'other' => q({0} й),
					},
				},
			} }
);

has 'yesstr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:ҳа|ҳ|yes|y)$' }
);

has 'nostr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:йўқ|й|no|n)$' }
);

has 'listPatterns' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
				start => q({0}, {1}),
				middle => q({0}, {1}),
				end => q({0}, {1}),
				2 => q({0}, {1}),
		} }
);

has 'number_symbols' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'arabext' => {
			'decimal' => q(٫),
			'exponential' => q(×۱۰^),
			'group' => q(٬),
			'infinity' => q(∞),
			'minusSign' => q(-),
			'nan' => q(NaN),
			'perMille' => q(؉),
			'percentSign' => q(٪),
			'plusSign' => q(+),
			'superscriptingExponent' => q(×),
		},
		'latn' => {
			'decimal' => q(,),
			'exponential' => q(E),
			'group' => q( ),
			'infinity' => q(∞),
			'minusSign' => q(-),
			'nan' => q(NaN),
			'perMille' => q(‰),
			'percentSign' => q(%),
			'plusSign' => q(+),
			'superscriptingExponent' => q(×),
		},
	} }
);

has 'number_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		decimalFormat => {
			'default' => {
				'1000' => {
					'one' => '0минг',
					'other' => '0минг',
				},
				'10000' => {
					'one' => '00минг',
					'other' => '00минг',
				},
				'100000' => {
					'one' => '000минг',
					'other' => '000минг',
				},
				'1000000' => {
					'one' => '0млн',
					'other' => '0млн',
				},
				'10000000' => {
					'one' => '00млн',
					'other' => '00млн',
				},
				'100000000' => {
					'one' => '000млн',
					'other' => '000млн',
				},
				'1000000000' => {
					'one' => '0млрд',
					'other' => '0млрд',
				},
				'10000000000' => {
					'one' => '00млрд',
					'other' => '00млрд',
				},
				'100000000000' => {
					'one' => '000млрд',
					'other' => '000млрд',
				},
				'1000000000000' => {
					'one' => '0трлн',
					'other' => '0трлн',
				},
				'10000000000000' => {
					'one' => '00трлн',
					'other' => '00трлн',
				},
				'100000000000000' => {
					'one' => '000трлн',
					'other' => '000трлн',
				},
				'standard' => {
					'' => '#,##0.###',
				},
			},
			'long' => {
				'1000' => {
					'one' => '0 минг',
					'other' => '0 минг',
				},
				'10000' => {
					'one' => '00 минг',
					'other' => '00 минг',
				},
				'100000' => {
					'one' => '000 минг',
					'other' => '000 минг',
				},
				'1000000' => {
					'one' => '0 миллион',
					'other' => '0 миллион',
				},
				'10000000' => {
					'one' => '00 миллион',
					'other' => '00 миллион',
				},
				'100000000' => {
					'one' => '000 миллион',
					'other' => '000 миллион',
				},
				'1000000000' => {
					'one' => '0 миллиард',
					'other' => '0 миллиард',
				},
				'10000000000' => {
					'one' => '00 миллиард',
					'other' => '00 миллиард',
				},
				'100000000000' => {
					'one' => '000 миллиард',
					'other' => '000 миллиард',
				},
				'1000000000000' => {
					'one' => '0 трилион',
					'other' => '0 трилион',
				},
				'10000000000000' => {
					'one' => '00 трилион',
					'other' => '00 трилион',
				},
				'100000000000000' => {
					'one' => '000 трилион',
					'other' => '000 трилион',
				},
			},
			'short' => {
				'1000' => {
					'one' => '0минг',
					'other' => '0минг',
				},
				'10000' => {
					'one' => '00минг',
					'other' => '00минг',
				},
				'100000' => {
					'one' => '000минг',
					'other' => '000минг',
				},
				'1000000' => {
					'one' => '0млн',
					'other' => '0млн',
				},
				'10000000' => {
					'one' => '00млн',
					'other' => '00млн',
				},
				'100000000' => {
					'one' => '000млн',
					'other' => '000млн',
				},
				'1000000000' => {
					'one' => '0млрд',
					'other' => '0млрд',
				},
				'10000000000' => {
					'one' => '00млрд',
					'other' => '00млрд',
				},
				'100000000000' => {
					'one' => '000млрд',
					'other' => '000млрд',
				},
				'1000000000000' => {
					'one' => '0трлн',
					'other' => '0трлн',
				},
				'10000000000000' => {
					'one' => '00трлн',
					'other' => '00трлн',
				},
				'100000000000000' => {
					'one' => '000трлн',
					'other' => '000трлн',
				},
			},
		},
		percentFormat => {
			'default' => {
				'standard' => {
					'' => '#,##0%',
				},
			},
		},
		scientificFormat => {
			'default' => {
				'standard' => {
					'' => '#E0',
				},
			},
		},
} },
);

has 'number_currency_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'arabext' => {
			'pattern' => {
				'default' => {
					'standard' => {
						'positive' => '¤ #,##0.00',
					},
				},
			},
		},
		'latn' => {
			'pattern' => {
				'default' => {
					'standard' => {
						'positive' => '¤ #,##0.00',
					},
				},
			},
		},
} },
);

has 'currencies' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'ANG' => {
			display_name => {
				'currency' => q(Голланд Антил гульдени),
				'one' => q(Голланд Антил гульдени),
				'other' => q(Голланд Антил гульдени),
			},
		},
		'ARS' => {
			display_name => {
				'currency' => q(Аргентина песоси),
				'one' => q(Аргентина песоси),
				'other' => q(Аргентина песоси),
			},
		},
		'AUD' => {
			symbol => 'A$',
		},
		'AWG' => {
			display_name => {
				'currency' => q(Аруба флорини),
				'one' => q(Аруба флорини),
				'other' => q(Аруба флорини),
			},
		},
		'BBD' => {
			display_name => {
				'currency' => q(Барбадос доллари),
				'one' => q(Барбадос доллари),
				'other' => q(Барбадос доллари),
			},
		},
		'BMD' => {
			display_name => {
				'currency' => q(Бермуда доллари),
				'one' => q(Бермуда доллари),
				'other' => q(Бермуда доллари),
			},
		},
		'BOB' => {
			display_name => {
				'currency' => q(Боливия болвиани),
				'one' => q(Боливия болвиани),
				'other' => q(Боливия болвиани),
			},
		},
		'BRL' => {
			symbol => 'R$',
			display_name => {
				'currency' => q(Бразил реали),
				'one' => q(Бразил реали),
				'other' => q(Бразил реали),
			},
		},
		'BSD' => {
			display_name => {
				'currency' => q(Багама доллари),
				'one' => q(Багама доллари),
				'other' => q(Багама доллари),
			},
		},
		'BZD' => {
			display_name => {
				'currency' => q(Белиз доллари),
				'one' => q(Белиз доллари),
				'other' => q(Белиз доллари),
			},
		},
		'CAD' => {
			symbol => 'CA$',
			display_name => {
				'currency' => q(Канада доллари),
				'one' => q(Канада доллари),
				'other' => q(Канада доллари),
			},
		},
		'CLP' => {
			display_name => {
				'currency' => q(Чили песоси),
				'one' => q(Чили песоси),
				'other' => q(Чили песоси),
			},
		},
		'CNY' => {
			symbol => 'CN¥',
			display_name => {
				'currency' => q(Хитой юани),
				'one' => q(Хитой юани),
				'other' => q(Хитой юани),
			},
		},
		'COP' => {
			display_name => {
				'currency' => q(Колумбия песоси),
				'one' => q(Колумбия песоси),
				'other' => q(Колумбия песоси),
			},
		},
		'CRC' => {
			display_name => {
				'currency' => q(Коста-Рика колони),
				'one' => q(Коста-Рика колони),
				'other' => q(Коста-Рика колони),
			},
		},
		'CUC' => {
			display_name => {
				'currency' => q(Куба Айирбошлаш песоси),
				'one' => q(Куба айирбошлаш песоси),
				'other' => q(Куба айирбошлаш песоси),
			},
		},
		'CUP' => {
			display_name => {
				'currency' => q(Куба песоси),
				'one' => q(Куба песоси),
				'other' => q(Куба песоси),
			},
		},
		'DOP' => {
			display_name => {
				'currency' => q(Доминикан песоси),
				'one' => q(Доминикан песоси),
				'other' => q(Доминикан песоси),
			},
		},
		'DZD' => {
			display_name => {
				'currency' => q(Жазоир динори),
				'one' => q(Жазоир динори),
				'other' => q(Жазоир динори),
			},
		},
		'EGP' => {
			display_name => {
				'currency' => q(Миср фунти),
				'one' => q(Миср фунти),
				'other' => q(Миср фунти),
			},
		},
		'EUR' => {
			symbol => '€',
			display_name => {
				'currency' => q(Евро),
				'one' => q(Евро),
				'other' => q(Евро),
			},
		},
		'FKP' => {
			display_name => {
				'currency' => q(Фолькленд ороли фунти),
				'one' => q(Фолькленд ороли фунти),
				'other' => q(Фолькленд ороли фунти),
			},
		},
		'GBP' => {
			symbol => '£',
			display_name => {
				'currency' => q(Инглиз фунт),
				'one' => q(Инглиз фунт),
				'other' => q(Инглиз фунт),
			},
		},
		'GTQ' => {
			display_name => {
				'currency' => q(Гватемала кветзали),
				'one' => q(Гватемала кветзали),
				'other' => q(Гватемала кветзали),
			},
		},
		'GYD' => {
			display_name => {
				'currency' => q(Гаяна доллари),
				'one' => q(Гаяна доллари),
				'other' => q(Гаяна доллари),
			},
		},
		'HKD' => {
			symbol => 'HK$',
		},
		'HNL' => {
			display_name => {
				'currency' => q(Гондурас лемпираси),
				'one' => q(Гондурас лемпираси),
				'other' => q(Гондурас лемпираси),
			},
		},
		'HTG' => {
			display_name => {
				'currency' => q(Гаити гурдаси),
				'one' => q(Гаити гурдаси),
				'other' => q(Гаити гурдаси),
			},
		},
		'ILS' => {
			symbol => '₪',
		},
		'INR' => {
			symbol => '₹',
			display_name => {
				'currency' => q(Ҳинд рупияси),
			},
		},
		'JMD' => {
			display_name => {
				'currency' => q(Ямайка доллари),
				'one' => q(Ямайка доллари),
				'other' => q(Ямайка доллари),
			},
		},
		'JPY' => {
			symbol => 'JP¥',
			display_name => {
				'currency' => q(Япон йенаси),
				'one' => q(Япон йенаси),
				'other' => q(Япон йенаси),
			},
		},
		'KRW' => {
			symbol => '₩',
		},
		'KYD' => {
			display_name => {
				'currency' => q(Кайман ороли Доллари),
				'one' => q(Кайман ороли доллари),
				'other' => q(Кайман ороли доллари),
			},
		},
		'LYD' => {
			display_name => {
				'currency' => q(Ливия динори),
				'one' => q(Ливия динори),
				'other' => q(Ливия динори),
			},
		},
		'MAD' => {
			display_name => {
				'currency' => q(Марокаш дирҳами),
				'one' => q(Марокаш дирҳами),
				'other' => q(Марокаш дирҳами),
			},
		},
		'MXN' => {
			symbol => 'MX$',
			display_name => {
				'currency' => q(Мексика песоси),
				'one' => q(Мексика песоси),
				'other' => q(Мексика песоси),
			},
		},
		'NIO' => {
			display_name => {
				'currency' => q(Никарагуа кордобаси),
				'one' => q(Никарагуа кордобаси),
				'other' => q(Никарагуа кордобаси),
			},
		},
		'NZD' => {
			symbol => 'NZ$',
		},
		'PAB' => {
			display_name => {
				'currency' => q(Панама бальбоаси),
				'one' => q(Панама бальбоаси),
				'other' => q(Панама бальбоаси),
			},
		},
		'PEN' => {
			display_name => {
				'currency' => q(Перу нуево сол),
				'one' => q(Перу нуево сол),
				'other' => q(Перу нуево сол),
			},
		},
		'PYG' => {
			display_name => {
				'currency' => q(Парагвай гуарани),
				'one' => q(Парагвай гуарани),
				'other' => q(Парагвай гуарани),
			},
		},
		'RON' => {
			symbol => 'RON',
		},
		'RUB' => {
			display_name => {
				'currency' => q(Рус рубли),
				'one' => q(Рус рубли),
				'other' => q(Рус рубли),
			},
		},
		'SRD' => {
			display_name => {
				'currency' => q(Суринам доллари),
				'one' => q(Суринам доллари),
				'other' => q(Суринам доллари),
			},
		},
		'THB' => {
			symbol => '฿',
		},
		'TTD' => {
			display_name => {
				'currency' => q(Тринидад ва Тобаго доллари),
				'one' => q(Тринидад ва Тобаго доллари),
				'other' => q(Тринидад ва Тобаго доллари),
			},
		},
		'TWD' => {
			symbol => 'NT$',
		},
		'USD' => {
			symbol => 'US$',
			display_name => {
				'currency' => q(АҚШ доллари),
				'one' => q(АҚШ доллари),
				'other' => q(АҚШ доллари),
			},
		},
		'UYU' => {
			display_name => {
				'currency' => q(Уругвай песоси),
				'one' => q(Уругвай песоси),
				'other' => q(Уругвай песоси),
			},
		},
		'UZS' => {
			symbol => 'сўм',
			display_name => {
				'currency' => q(Ўзбекистон сўм),
				'one' => q(Ўзбекистон сўм),
				'other' => q(Ўзбекистон сўм),
			},
		},
		'VEF' => {
			display_name => {
				'currency' => q(Венесуэла боливари),
				'one' => q(Венесуэла боливари),
				'other' => q(Венесуэла боливари),
			},
		},
		'VND' => {
			symbol => '₫',
		},
		'XAF' => {
			symbol => 'FCFA',
		},
		'XCD' => {
			symbol => 'EC$',
			display_name => {
				'currency' => q(Шарқий Кариб доллари),
				'one' => q(Шарқ Кариб доллари),
				'other' => q(Шарқ Кариб доллари),
			},
		},
		'XOF' => {
			symbol => 'CFA',
		},
		'XPF' => {
			symbol => 'CFPF',
		},
	} },
);


has 'calendar_months' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {
						nonleap => [
							'Янв',
							'Фев',
							'Мар',
							'Апр',
							'Май',
							'Июн',
							'Июл',
							'Авг',
							'Сен',
							'Окт',
							'Ноя',
							'Дек'
						],
						leap => [
							
						],
					},
					narrow => {
						nonleap => [
							'Я',
							'Ф',
							'М',
							'А',
							'М',
							'И',
							'И',
							'А',
							'С',
							'О',
							'Н',
							'Д'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'Январ',
							'Феврал',
							'Март',
							'Апрел',
							'Май',
							'Июн',
							'Июл',
							'Август',
							'Сентябр',
							'Октябр',
							'Ноябр',
							'Декабр'
						],
						leap => [
							
						],
					},
				},
				'stand-alone' => {
					abbreviated => {
						nonleap => [
							'Янв',
							'Фев',
							'Мар',
							'Апр',
							'Май',
							'Июн',
							'Июл',
							'Авг',
							'Сен',
							'Окт',
							'Ноя',
							'Дек'
						],
						leap => [
							
						],
					},
					narrow => {
						nonleap => [
							'Я',
							'Ф',
							'М',
							'А',
							'М',
							'И',
							'И',
							'А',
							'С',
							'О',
							'Н',
							'Д'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'Январ',
							'Феврал',
							'Март',
							'Апрел',
							'Май',
							'Июн',
							'Июл',
							'Август',
							'Сентябр',
							'Октябр',
							'Ноябр',
							'Декабр'
						],
						leap => [
							
						],
					},
				},
			},
			'islamic' => {
				'format' => {
					wide => {
						nonleap => [
							'Муҳаррам',
							'Сафар',
							'Рабиул-аввал',
							'Рабиул-охир',
							'Жумодиул-уло',
							'Жумодиул-ухро',
							'Ражаб',
							'Шаъбон',
							'Рамазон',
							'Шаввол',
							'Зил-қаъда',
							'Зил-ҳижжа'
						],
						leap => [
							
						],
					},
				},
			},
	} },
);

has 'calendar_days' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {
						mon => 'Душ',
						tue => 'Сеш',
						wed => 'Чор',
						thu => 'Пай',
						fri => 'Жум',
						sat => 'Шан',
						sun => 'Якш'
					},
					narrow => {
						mon => 'Д',
						tue => 'С',
						wed => 'Ч',
						thu => 'П',
						fri => 'Ж',
						sat => 'Ш',
						sun => 'Я'
					},
					short => {
						mon => 'Душ',
						tue => 'Сеш',
						wed => 'Чор',
						thu => 'Пай',
						fri => 'Жум',
						sat => 'Шан',
						sun => 'Якш'
					},
					wide => {
						mon => 'душанба',
						tue => 'сешанба',
						wed => 'чоршанба',
						thu => 'пайшанба',
						fri => 'жума',
						sat => 'шанба',
						sun => 'якшанба'
					},
				},
				'stand-alone' => {
					abbreviated => {
						mon => 'Душ',
						tue => 'Сеш',
						wed => 'Чор',
						thu => 'Пай',
						fri => 'Жум',
						sat => 'Шан',
						sun => 'Якш'
					},
					narrow => {
						mon => 'Д',
						tue => 'С',
						wed => 'Ч',
						thu => 'П',
						fri => 'Ж',
						sat => 'Ш',
						sun => 'Я'
					},
					short => {
						mon => 'Душ',
						tue => 'Сеш',
						wed => 'Чор',
						thu => 'Пай',
						fri => 'Жум',
						sat => 'Шан',
						sun => 'Якш'
					},
					wide => {
						mon => 'душанба',
						tue => 'сешанба',
						wed => 'чоршанба',
						thu => 'пайшанба',
						fri => 'жума',
						sat => 'шанба',
						sun => 'якшанба'
					},
				},
			},
	} },
);

has 'calendar_quarters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {0 => '1-ч',
						1 => '2-ч',
						2 => '3-ч',
						3 => '4-ч'
					},
					narrow => {0 => '1',
						1 => '2',
						2 => '3',
						3 => '4'
					},
					wide => {0 => '1-чорак',
						1 => '2-чорак',
						2 => '3-чорак',
						3 => '4-чорак'
					},
				},
				'stand-alone' => {
					abbreviated => {0 => '1-ч',
						1 => '2-ч',
						2 => '3-ч',
						3 => '4-ч'
					},
					narrow => {0 => '1',
						1 => '2',
						2 => '3',
						3 => '4'
					},
					wide => {0 => '1-чорак',
						1 => '2-чорак',
						2 => '3-чорак',
						3 => '4-чорак'
					},
				},
			},
	} },
);

has 'day_period_data' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub { sub {
		# Time in hhmm format
		my ($self, $type, $time, $day_period_type) = @_;
		$day_period_type //= 'default';
		SWITCH:
		for ($type) {
			if ($_ eq 'generic') {
				if($day_period_type eq 'selection') {
					return 'evening1' if $time >= 1800
						&& $time < 2200;
					return 'afternoon1' if $time >= 1100
						&& $time < 1800;
					return 'morning1' if $time >= 600
						&& $time < 1100;
					return 'night1' if $time >= 2200;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'noon' if $time == 1200;
					return 'afternoon1' if $time >= 1100
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2200;
					return 'morning1' if $time >= 600
						&& $time < 1100;
					return 'night1' if $time >= 2200;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'islamic') {
				if($day_period_type eq 'selection') {
					return 'evening1' if $time >= 1800
						&& $time < 2200;
					return 'afternoon1' if $time >= 1100
						&& $time < 1800;
					return 'morning1' if $time >= 600
						&& $time < 1100;
					return 'night1' if $time >= 2200;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'noon' if $time == 1200;
					return 'afternoon1' if $time >= 1100
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2200;
					return 'morning1' if $time >= 600
						&& $time < 1100;
					return 'night1' if $time >= 2200;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'gregorian') {
				if($day_period_type eq 'selection') {
					return 'evening1' if $time >= 1800
						&& $time < 2200;
					return 'afternoon1' if $time >= 1100
						&& $time < 1800;
					return 'morning1' if $time >= 600
						&& $time < 1100;
					return 'night1' if $time >= 2200;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'noon' if $time == 1200;
					return 'afternoon1' if $time >= 1100
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2200;
					return 'morning1' if $time >= 600
						&& $time < 1100;
					return 'night1' if $time >= 2200;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
		}
	} },
);

around day_period_data => sub {
	my ($orig, $self) = @_;
	return $self->$orig;
};

has 'eras' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
		},
		'gregorian' => {
			abbreviated => {
				'0' => 'М.А.',
				'1' => 'Э'
			},
		},
		'islamic' => {
		},
	} },
);

has 'date_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			'full' => q{EEEE, G y MMMM dd},
			'long' => q{G y MMMM d},
			'medium' => q{G y MMM d},
			'short' => q{GGGGG y/MM/dd},
		},
		'gregorian' => {
			'full' => q{EEEE, y MMMM dd},
			'long' => q{y MMMM d},
			'medium' => q{y MMM d},
			'short' => q{dd/MM/yy},
		},
		'islamic' => {
		},
	} },
);

has 'time_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
		},
		'gregorian' => {
			'full' => q{HH:mm:ss zzzz},
			'long' => q{HH:mm:ss z},
			'medium' => q{HH:mm:ss},
			'short' => q{HH:mm},
		},
		'islamic' => {
		},
	} },
);

has 'datetime_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			'full' => q{{1} {0}},
			'long' => q{{1} {0}},
			'medium' => q{{1} {0}},
			'short' => q{{1} {0}},
		},
		'gregorian' => {
			'full' => q{{1} {0}},
			'long' => q{{1} {0}},
			'medium' => q{{1} {0}},
			'short' => q{{1} {0}},
		},
		'islamic' => {
		},
	} },
);

has 'datetime_formats_available_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'gregorian' => {
			EHm => q{E HH:mm},
			EHms => q{E HH:mm:ss},
			Ed => q{d, E},
			Ehm => q{E h:mm a},
			Ehms => q{E h:mm:ss a},
			Gy => q{G y},
			GyMMM => q{G y MMM},
			GyMMMEd => q{G y MMM d, E},
			GyMMMd => q{G y MMM d},
			H => q{HH},
			Hm => q{HH:mm},
			Hms => q{HH:mm:ss},
			M => q{L},
			MEd => q{MM-dd, E},
			MMM => q{LLL},
			MMMEd => q{MMM d, E},
			MMMd => q{MMM d},
			Md => q{MM-dd},
			d => q{d},
			h => q{h a},
			hm => q{h:mm a},
			hms => q{h:mm:ss a},
			ms => q{mm:ss},
			y => q{y},
			yM => q{y-MM},
			yMEd => q{y-MM-dd, E},
			yMMM => q{y MMM},
			yMMMEd => q{y MMM d, E},
			yMMMM => q{y MMMM},
			yMMMd => q{y MMM d},
			yMd => q{y-MM-dd},
			yQQQ => q{y QQQ},
			yQQQQ => q{y QQQQ},
		},
		'generic' => {
			Ed => q{d, E},
			Gy => q{G y},
			GyMMM => q{G y MMM},
			GyMMMEd => q{G y MMM d, E},
			GyMMMd => q{G y MMM d},
			M => q{L},
			MEd => q{MM-dd, E},
			MMM => q{LLL},
			MMMEd => q{MMM d, E},
			MMMd => q{MMM d},
			Md => q{MM-dd},
			d => q{d},
			y => q{G y},
			yyyy => q{G y},
			yyyyM => q{GGGGG y-MM},
			yyyyMEd => q{GGGGG y-MM-dd, E},
			yyyyMMM => q{G y MMM},
			yyyyMMMEd => q{G y MMM d, E},
			yyyyMMMd => q{G y MMM d},
			yyyyMd => q{GGGGG y-MM-dd},
			yyyyQQQ => q{G y QQQ},
			yyyyQQQQ => q{G y QQQQ},
		},
	} },
);

has 'datetime_formats_append_item' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'gregorian' => {
			'Timezone' => '{0} {1}',
		},
	} },
);

has 'datetime_formats_interval' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'gregorian' => {
			H => {
				H => q{HH–HH},
			},
			Hm => {
				H => q{HH:mm–HH:mm},
				m => q{HH:mm–HH:mm},
			},
			Hmv => {
				H => q{HH:mm–HH:mm v},
				m => q{HH:mm–HH:mm v},
			},
			Hv => {
				H => q{HH–HH v},
			},
			M => {
				M => q{MM–MM},
			},
			MEd => {
				M => q{MM-dd, E – MM-dd, E},
				d => q{MM-dd, E – MM-dd, E},
			},
			MMM => {
				M => q{LLL–LLL},
			},
			MMMEd => {
				M => q{MMM d, E – MMM d, E},
				d => q{MMM d, E – MMM d, E},
			},
			MMMd => {
				M => q{MMM d – MMM d},
				d => q{MMM d–d},
			},
			Md => {
				M => q{MM-dd – MM-dd},
				d => q{MM-dd – MM-dd},
			},
			d => {
				d => q{d–d},
			},
			fallback => '{0} – {1}',
			h => {
				a => q{h a – h a},
				h => q{h–h a},
			},
			hm => {
				a => q{h:mm a – h:mm a},
				h => q{h:mm–h:mm a},
				m => q{h:mm–h:mm a},
			},
			hmv => {
				a => q{h:mm a – h:mm a v},
				h => q{h:mm–h:mm a v},
				m => q{h:mm–h:mm a v},
			},
			hv => {
				a => q{h a – h a v},
				h => q{h–h a v},
			},
			y => {
				y => q{y–y},
			},
			yM => {
				M => q{y-MM – y-MM},
				y => q{y-MM – y-MM},
			},
			yMEd => {
				M => q{y-MM-dd, E – y-MM-dd, E},
				d => q{y-MM-dd, E – y-MM-dd, E},
				y => q{y-MM-dd, E – y-MM-dd, E},
			},
			yMMM => {
				M => q{y MMM–MMM},
				y => q{y MMM – y MMM},
			},
			yMMMEd => {
				M => q{y MMM d, E – MMM d, E},
				d => q{y MMM d, E – MMM d, E},
				y => q{y MMM d, E – y MMM d, E},
			},
			yMMMM => {
				M => q{y MMMM–MMMM},
				y => q{y MMMM – y MMMM},
			},
			yMMMd => {
				M => q{y MMM d – MMM d},
				d => q{y MMM d–d},
				y => q{y MMM d – y MMM d},
			},
			yMd => {
				M => q{y-MM-dd – y-MM-dd},
				d => q{y-MM-dd – y-MM-dd},
				y => q{y-MM-dd – y-MM-dd},
			},
		},
		'generic' => {
			M => {
				M => q{MM–MM},
			},
			MEd => {
				M => q{MM-dd, E – MM-dd, E},
				d => q{MM-dd, E – MM-dd, E},
			},
			MMM => {
				M => q{LLL–LLL},
			},
			MMMEd => {
				M => q{MMM d, E – MMM d, E},
				d => q{MMM d, E – MMM d, E},
			},
			MMMd => {
				M => q{MMM d – MMM d},
				d => q{MMM d–d},
			},
			Md => {
				M => q{MM-dd – MM-dd},
				d => q{MM-dd – MM-dd},
			},
			d => {
				d => q{d–d},
			},
			fallback => '{0} – {1}',
			y => {
				y => q{G y–y},
			},
			yM => {
				M => q{GGGGG y-MM – y-MM},
				y => q{GGGGG y-MM – y-MM},
			},
			yMEd => {
				M => q{GGGGG y-MM-dd, E – y-MM-dd, E},
				d => q{GGGGG y-MM-dd, E – y-MM-dd, E},
				y => q{GGGGG y-MM-dd, E – y-MM-dd, E},
			},
			yMMM => {
				M => q{G y MMM–MMM},
				y => q{G y MMM – y MMM},
			},
			yMMMEd => {
				M => q{G y MMM d, E – MMM d, E},
				d => q{G y MMM d, E – MMM d, E},
				y => q{G y MMM d, E – y MMM d, E},
			},
			yMMMM => {
				M => q{G y MMMM–MMMM},
				y => q{G y MMMM – y MMMM},
			},
			yMMMd => {
				M => q{G y MMM d – MMM d},
				d => q{G y MMM d–d},
				y => q{G y MMM d – y MMM d},
			},
			yMd => {
				M => q{GGGGG y-MM-dd – y-MM-dd},
				d => q{GGGGG y-MM-dd – y-MM-dd},
				y => q{GGGGG y-MM-dd – y-MM-dd},
			},
		},
	} },
);

has 'time_zone_names' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default	=> sub { {
		hourFormat => q(+HH:mm;-HH:mm),
		gmtFormat => q(GMT{0}),
		gmtZeroFormat => q(GMT),
		regionFormat => q({0} вақти),
		regionFormat => q({0} кундузги вақти),
		regionFormat => q({0} стандарт вақти),
		fallbackFormat => q({1} ({0})),
		'Afghanistan' => {
			long => {
				'standard' => q(Афғонистон вақти),
			},
		},
		'Africa/Asmera' => {
			exemplarCity => q#Asmara#,
		},
		'Africa_Central' => {
			long => {
				'standard' => q(Марказий Африка вақти),
			},
		},
		'Africa_Eastern' => {
			long => {
				'standard' => q(Шарқий Африка вақти),
			},
		},
		'Africa_Southern' => {
			long => {
				'standard' => q(Жанубий Африка вақти),
			},
		},
		'Africa_Western' => {
			long => {
				'daylight' => q(Ғарбий Африка ёзги вақти),
				'generic' => q(Ғарбий Африка вақти),
				'standard' => q(Ғарбий Африка стандарт вақти),
			},
		},
		'Alaska' => {
			long => {
				'daylight' => q(Аляска кундузги вақти),
				'generic' => q(Аляска вақти),
				'standard' => q(Аляска стандарт вақти),
			},
		},
		'Amazon' => {
			long => {
				'daylight' => q(Амазонка ёзги вақти),
				'generic' => q(Амазонка вақти),
				'standard' => q(Амазонка стандарт вақти),
			},
		},
		'America/Coral_Harbour' => {
			exemplarCity => q#Atikokan#,
		},
		'America/Godthab' => {
			exemplarCity => q#Nuuk#,
		},
		'America/Indiana/Knox' => {
			exemplarCity => q#Knox, Indiana#,
		},
		'America/Indiana/Marengo' => {
			exemplarCity => q#Marengo, Indiana#,
		},
		'America/Indiana/Petersburg' => {
			exemplarCity => q#Petersburg, Indiana#,
		},
		'America/Indiana/Tell_City' => {
			exemplarCity => q#Tell City, Indiana#,
		},
		'America/Indiana/Vevay' => {
			exemplarCity => q#Vevay, Indiana#,
		},
		'America/Indiana/Vincennes' => {
			exemplarCity => q#Vincennes, Indiana#,
		},
		'America/Indiana/Winamac' => {
			exemplarCity => q#Winamac, Indiana#,
		},
		'America/Kentucky/Monticello' => {
			exemplarCity => q#Monticello, Kentucky#,
		},
		'America/Lower_Princes' => {
			exemplarCity => q#Lower Princeʼs Quarter#,
		},
		'America/North_Dakota/Beulah' => {
			exemplarCity => q#Beulah, North Dakota#,
		},
		'America/North_Dakota/Center' => {
			exemplarCity => q#Center, North Dakota#,
		},
		'America/North_Dakota/New_Salem' => {
			exemplarCity => q#New Salem, North Dakota#,
		},
		'America/Scoresbysund' => {
			exemplarCity => q#Ittoqqortoormiit#,
		},
		'America/St_Barthelemy' => {
			exemplarCity => q#St. Barthelemy#,
		},
		'America/St_Johns' => {
			exemplarCity => q#St. John’s#,
		},
		'America/St_Kitts' => {
			exemplarCity => q#St. Kitts#,
		},
		'America/St_Lucia' => {
			exemplarCity => q#St. Lucia#,
		},
		'America/St_Thomas' => {
			exemplarCity => q#St. Thomas#,
		},
		'America/St_Vincent' => {
			exemplarCity => q#St. Vincent#,
		},
		'America_Central' => {
			long => {
				'daylight' => q(Шимолий Америка марказий кундузги вақти),
				'generic' => q(Шимолий Америка),
				'standard' => q(Шимолий Америка марказий стандарт вақти),
			},
		},
		'America_Eastern' => {
			long => {
				'daylight' => q(Шимолий Америка шарқий кундузги вақти),
				'generic' => q(Шимолий Америка шарқий вақти),
				'standard' => q(Шимолий Америка шарқий стандарт вақти),
			},
		},
		'America_Mountain' => {
			long => {
				'daylight' => q(Шимолий Америка тоғ кундузги вақти),
				'generic' => q(Шимолий Америка тоғ вақти),
				'standard' => q(Шимолий Америка тоғ стандарт вақти),
			},
		},
		'America_Pacific' => {
			long => {
				'daylight' => q(Шимолий Америка тинч океани кундузги вақти),
				'generic' => q(Шимолий Америка тинч океани вақти),
				'standard' => q(Шимолий Америка тинч океани стандарт вақти),
			},
		},
		'Antarctica/DumontDUrville' => {
			exemplarCity => q#Dumont d’Urville#,
		},
		'Arabian' => {
			long => {
				'daylight' => q(Арабистон кундузги вақти),
				'generic' => q(Арабистон вақти),
				'standard' => q(Арабистон стандарт вақти),
			},
		},
		'Argentina' => {
			long => {
				'daylight' => q(Аргентина ёзги вақти),
				'generic' => q(Аргентина вақти),
				'standard' => q(Аргентина стандарт вақти),
			},
		},
		'Argentina_Western' => {
			long => {
				'daylight' => q(Ғарбий Аргентина ёзги вақти),
				'generic' => q(Ғарбий Аргентина вақти),
				'standard' => q(Ғарбий Аргентина стандарт вақти),
			},
		},
		'Armenia' => {
			long => {
				'daylight' => q(Арманистон ёзги вақти),
				'generic' => q(Арамнистон вақти),
				'standard' => q(Арманистон стандарт вақти),
			},
		},
		'Asia/Calcutta' => {
			exemplarCity => q#Kolkata#,
		},
		'Asia/Katmandu' => {
			exemplarCity => q#Kathmandu#,
		},
		'Asia/Saigon' => {
			exemplarCity => q#Ho Chi Minh#,
		},
		'Atlantic' => {
			long => {
				'daylight' => q(Атлантика кундузги вақти),
				'generic' => q(Атлантика вақти),
				'standard' => q(Атлантика стандарт вақти),
			},
		},
		'Atlantic/Faeroe' => {
			exemplarCity => q#Faroe#,
		},
		'Atlantic/St_Helena' => {
			exemplarCity => q#St. Helena#,
		},
		'Australia_Central' => {
			long => {
				'daylight' => q(Марказий Австралия кундузги вақти),
				'generic' => q(Марказий Австралия вақти),
				'standard' => q(Марказий Австралия стандарт вақти),
			},
		},
		'Australia_CentralWestern' => {
			long => {
				'daylight' => q(Марказий Австралия Ғарбий кундузги вақти),
				'generic' => q(Марказий Австралия Ғарбий вақти),
				'standard' => q(Марказий Австралия Ғарбий стандарт вақти),
			},
		},
		'Australia_Eastern' => {
			long => {
				'daylight' => q(Шарқий Австралия кундузги вақти),
				'generic' => q(Шарқий Австралия вақти),
				'standard' => q(Шарқий Австралия стандарт вақти),
			},
		},
		'Australia_Western' => {
			long => {
				'daylight' => q(Ғарбий Австралия кундузги вақти),
				'generic' => q(Ғарбий Австралия вақти),
				'standard' => q(Ғарбий Австралия стандарт вақти),
			},
		},
		'Azerbaijan' => {
			long => {
				'daylight' => q(Озарбайжон ёзги вақти),
				'generic' => q(Озарбайжон вақти),
				'standard' => q(Озарбайжон стандарт вақти),
			},
		},
		'Azores' => {
			long => {
				'daylight' => q(Азор ёзги вақти),
				'generic' => q(Азор вақти),
				'standard' => q(Азор стандарт вақти),
			},
		},
		'Bangladesh' => {
			long => {
				'daylight' => q(Бангладеш ёзги вақти),
				'generic' => q(Бангладеш вақти),
				'standard' => q(Бангладеш стандарт вақти),
			},
		},
		'Bhutan' => {
			long => {
				'standard' => q(Бутан вақти),
			},
		},
		'Bolivia' => {
			long => {
				'standard' => q(Боливия вақти),
			},
		},
		'Brasilia' => {
			long => {
				'daylight' => q(Бразилия ёзги вақти),
				'generic' => q(Бразилия вақти),
				'standard' => q(Бразилия стандарт вақти),
			},
		},
		'Brunei' => {
			long => {
				'standard' => q(Бруней Даруссалом вақти),
			},
		},
		'Cape_Verde' => {
			long => {
				'daylight' => q(Кабо-Верде ёзги вақти),
				'generic' => q(Кабо-Верде вақти),
				'standard' => q(Кабо-Верде стандарт вақти),
			},
		},
		'Chamorro' => {
			long => {
				'standard' => q(Каморро вақти),
			},
		},
		'Chatham' => {
			long => {
				'daylight' => q(Чатхам кундузги вақти),
				'generic' => q(Чатхам вақти),
				'standard' => q(Чатхам стандарт вақти),
			},
		},
		'Chile' => {
			long => {
				'daylight' => q(Чили ёзги вақти),
				'generic' => q(Чили вақти),
				'standard' => q(Чили стандарт вақти),
			},
		},
		'China' => {
			long => {
				'daylight' => q(Хитой кундузги вақти),
				'generic' => q(Хитой вақти),
				'standard' => q(Хитой стандарт вақти),
			},
		},
		'Choibalsan' => {
			long => {
				'daylight' => q(Чойбалсан ёзги вақти),
				'generic' => q(Чойбалсан вақти),
				'standard' => q(Чойбалсан стандарт вақти),
			},
		},
		'Christmas' => {
			long => {
				'standard' => q(Рождество ороли вақти),
			},
		},
		'Cocos' => {
			long => {
				'standard' => q(Кокос ороллари вақти),
			},
		},
		'Colombia' => {
			long => {
				'daylight' => q(Колумбия ёзги вақти),
				'generic' => q(Колумбия вақти),
				'standard' => q(Колумбия стандарт вақти),
			},
		},
		'Cook' => {
			long => {
				'daylight' => q(Кук ороллари ярим ёзги вақти),
				'generic' => q(Кук ороллари вақти),
				'standard' => q(Кук ороллари стандарт вақти),
			},
		},
		'Cuba' => {
			long => {
				'daylight' => q(Куба кундузги вақти),
				'generic' => q(Куба вақти),
				'standard' => q(Куба стандарт вақти),
			},
		},
		'Davis' => {
			long => {
				'standard' => q(Дэвис вақти),
			},
		},
		'DumontDUrville' => {
			long => {
				'standard' => q(Думонт-д-Урвил вақти),
			},
		},
		'East_Timor' => {
			long => {
				'standard' => q(Шарқий Тимор вақти),
			},
		},
		'Easter' => {
			long => {
				'daylight' => q(Пасхи ороли ёзги вақти),
				'generic' => q(Пасхи Ороли вақти),
				'standard' => q(Пасхи ороли стандарт вақти),
			},
		},
		'Ecuador' => {
			long => {
				'standard' => q(Эквадор вақти),
			},
		},
		'Etc/Unknown' => {
			exemplarCity => q#Номаълум#,
		},
		'Europe/Dublin' => {
			long => {
				'daylight' => q(Ирландия ёзги вақти),
			},
		},
		'Europe/London' => {
			long => {
				'daylight' => q(Британия ёзги вақти),
			},
		},
		'Europe_Central' => {
			long => {
				'daylight' => q(Марказий Европа ёзги вақти),
				'generic' => q(Марказий Европа вақти),
				'standard' => q(Марказий Европа стандарт вақти),
			},
		},
		'Europe_Eastern' => {
			long => {
				'daylight' => q(Шарқий Европа ёзги вақти),
				'generic' => q(Шарқий Европа вақти),
				'standard' => q(Шарқий Европа стандарт вақти),
			},
		},
		'Europe_Western' => {
			long => {
				'daylight' => q(Ғарбий Европа ёзги вақти),
				'generic' => q(Ғарбий Европа вақти),
				'standard' => q(Ғарбий Европа стандарт вақти),
			},
		},
		'Falkland' => {
			long => {
				'daylight' => q(Фолькленд ороллари ёзги вақти),
				'generic' => q(Фолькленд ороллари вақти),
				'standard' => q(Фолькленд ороллари стандарт вақти),
			},
		},
		'Fiji' => {
			long => {
				'daylight' => q(Фижи ёзги вақти),
				'generic' => q(Фижи вақти),
				'standard' => q(Фижи стандарт вақти),
			},
		},
		'French_Guiana' => {
			long => {
				'standard' => q(Француз Гвианаси вақти),
			},
		},
		'French_Southern' => {
			long => {
				'standard' => q(Француз жанубий ва Антарктика вақти),
			},
		},
		'GMT' => {
			long => {
				'standard' => q(Гринвич вақти),
			},
		},
		'Galapagos' => {
			long => {
				'standard' => q(Галапагос вақти),
			},
		},
		'Gambier' => {
			long => {
				'standard' => q(Гамбиер вақти),
			},
		},
		'Georgia' => {
			long => {
				'daylight' => q(Грузия ёзги вақти),
				'generic' => q(Грузия вақти),
				'standard' => q(Грузия стандарт вақти),
			},
		},
		'Gilbert_Islands' => {
			long => {
				'standard' => q(Гилберт ороллари вақти),
			},
		},
		'Greenland_Eastern' => {
			long => {
				'daylight' => q(Шарқий Гренландия ёзги вақти),
				'generic' => q(Шарқий Гренландия вақти),
				'standard' => q(Шарқий Гренландия стандарт вақти),
			},
		},
		'Greenland_Western' => {
			long => {
				'daylight' => q(Ғарбий Гренландия ёзги вақти),
				'generic' => q(Ғарбий Гренландия вақти),
				'standard' => q(Ғарбий Гренландия стандарт вақти),
			},
		},
		'Gulf' => {
			long => {
				'standard' => q(Кўрфаз вақти),
			},
		},
		'Guyana' => {
			long => {
				'standard' => q(Гайана вақти),
			},
		},
		'Hawaii_Aleutian' => {
			long => {
				'daylight' => q(Гавайи-алеут кундузги вақти),
				'generic' => q(Гавайи-алеут вақти),
				'standard' => q(Гавайи-алеут стандарт вақти),
			},
		},
		'Hong_Kong' => {
			long => {
				'daylight' => q(Гонконг ёзги вақти),
				'generic' => q(Гонконг вақти),
				'standard' => q(Гонконг стандарт вақти),
			},
		},
		'Hovd' => {
			long => {
				'daylight' => q(Ховд ёзги вақти),
				'generic' => q(Ховд вақти),
				'standard' => q(Ховд стандарт вақти),
			},
		},
		'India' => {
			long => {
				'standard' => q(Ҳиндистон вақти),
			},
		},
		'Indian_Ocean' => {
			long => {
				'standard' => q(Ҳинд океани вақти),
			},
		},
		'Indochina' => {
			long => {
				'standard' => q(Ҳинд-Хитой вақти),
			},
		},
		'Indonesia_Central' => {
			long => {
				'standard' => q(Марказий Индонезия вақти),
			},
		},
		'Indonesia_Eastern' => {
			long => {
				'standard' => q(Шарқий Индонезия вақти),
			},
		},
		'Indonesia_Western' => {
			long => {
				'standard' => q(Ғарбий Индонезия вақти),
			},
		},
		'Iran' => {
			long => {
				'daylight' => q(Эрон кундузги вақти),
				'generic' => q(Эрон вақти),
				'standard' => q(Эрон стандарт вақти),
			},
		},
		'Irkutsk' => {
			long => {
				'daylight' => q(Иркутск ёзги вақти),
				'generic' => q(Иркутск вақти),
				'standard' => q(Иркутск стандарт вақти),
			},
		},
		'Israel' => {
			long => {
				'daylight' => q(Исроил кундузги вақти),
				'generic' => q(Исроил вақти),
				'standard' => q(Исроил стандарт вақти),
			},
		},
		'Japan' => {
			long => {
				'daylight' => q(Япония кундузги вақти),
				'generic' => q(Япония вақти),
				'standard' => q(Япония стандарт вақти),
			},
		},
		'Kazakhstan_Eastern' => {
			long => {
				'standard' => q(Шарқий Қозоғистон вақти),
			},
		},
		'Kazakhstan_Western' => {
			long => {
				'standard' => q(Ғарбий Қозоғистон вақти),
			},
		},
		'Korea' => {
			long => {
				'daylight' => q(Корея кундузги вақти),
				'generic' => q(Корея вақти),
				'standard' => q(Корея стандарт вақти),
			},
		},
		'Kosrae' => {
			long => {
				'standard' => q(Косрае вақти),
			},
		},
		'Krasnoyarsk' => {
			long => {
				'daylight' => q(Красноярск ёзги вақти),
				'generic' => q(Красноярск вақти),
				'standard' => q(Красноярск стандарт вақти),
			},
		},
		'Kyrgystan' => {
			long => {
				'standard' => q(Қирғизистон вақти),
			},
		},
		'Line_Islands' => {
			long => {
				'standard' => q(Лайн ороллари вақти),
			},
		},
		'Lord_Howe' => {
			long => {
				'daylight' => q(Лорд Хове кундузги вақти),
				'generic' => q(Лорд Хове вақти),
				'standard' => q(Лорд Хове стандарт вақти),
			},
		},
		'Macquarie' => {
			long => {
				'standard' => q(Маквари ороли вақти),
			},
		},
		'Magadan' => {
			long => {
				'daylight' => q(Магадан ёзги вақти),
				'generic' => q(Магадан вақти),
				'standard' => q(Магадан стандарт вақти),
			},
		},
		'Malaysia' => {
			long => {
				'standard' => q(Малайзия вақти),
			},
		},
		'Maldives' => {
			long => {
				'standard' => q(Мальдив ороллар),
			},
		},
		'Marquesas' => {
			long => {
				'standard' => q(Маркезас вақти),
			},
		},
		'Marshall_Islands' => {
			long => {
				'standard' => q(Маршалл ороллари вақти),
			},
		},
		'Mauritius' => {
			long => {
				'daylight' => q(Маврикий ёзги вақти),
				'generic' => q(Маврикий вақти),
				'standard' => q(Маврикий стандарт вақти),
			},
		},
		'Mawson' => {
			long => {
				'standard' => q(Моувсон вақти),
			},
		},
		'Mongolia' => {
			long => {
				'daylight' => q(Улан-Батор ёзги вақти),
				'generic' => q(Улан-Батор вақти),
				'standard' => q(Улан-Батор стандарт вақти),
			},
		},
		'Moscow' => {
			long => {
				'daylight' => q(Москва ёзги вақти),
				'generic' => q(Москва вақти),
				'standard' => q(Москва стандарт вақти),
			},
		},
		'Myanmar' => {
			long => {
				'standard' => q(Мьянма вақти),
			},
		},
		'Nauru' => {
			long => {
				'standard' => q(Науру вақти),
			},
		},
		'Nepal' => {
			long => {
				'standard' => q(Непал вақти),
			},
		},
		'New_Caledonia' => {
			long => {
				'daylight' => q(Янги Каледония ёзги вақти),
				'generic' => q(Янги Каледония вақти),
				'standard' => q(Янги Каледония стандарт вақти),
			},
		},
		'New_Zealand' => {
			long => {
				'daylight' => q(Янги Зеландия кундузги вақти),
				'generic' => q(Янги Зеландия вақти),
				'standard' => q(Янги Зеландия стандарт вақти),
			},
		},
		'Newfoundland' => {
			long => {
				'daylight' => q(Ньюфаундленд кундузги вақти),
				'generic' => q(Ньюфаундленд вақти),
				'standard' => q(Ньюфаундленд стандарт вақти),
			},
		},
		'Niue' => {
			long => {
				'standard' => q(Ниуе вақти),
			},
		},
		'Norfolk' => {
			long => {
				'standard' => q(Норфолк ороли вақти),
			},
		},
		'Noronha' => {
			long => {
				'daylight' => q(Фернандо де Норонья ёзги вақти),
				'generic' => q(Фернандо де Норонья вақти),
				'standard' => q(Фернандо де Норонья стандарт вақти),
			},
		},
		'Novosibirsk' => {
			long => {
				'daylight' => q(Новосибирск ёзги вақти),
				'generic' => q(Новосибирск вақти),
				'standard' => q(Новосибирск стандарт вақти),
			},
		},
		'Omsk' => {
			long => {
				'daylight' => q(Омск ёзги вақти),
				'generic' => q(Омск вақти),
				'standard' => q(Омск стандарт вақти),
			},
		},
		'Pacific/Ponape' => {
			exemplarCity => q#Pohnpei#,
		},
		'Pacific/Truk' => {
			exemplarCity => q#Chuuk#,
		},
		'Pakistan' => {
			long => {
				'daylight' => q(Покистон ёзги вақти),
				'generic' => q(Покистон вақти),
				'standard' => q(Покистон стандарт вақти),
			},
		},
		'Palau' => {
			long => {
				'standard' => q(Палау вақти),
			},
		},
		'Papua_New_Guinea' => {
			long => {
				'standard' => q(Папуа-Янги Гвинея вақти),
			},
		},
		'Paraguay' => {
			long => {
				'daylight' => q(Парагвай ёзги вақти),
				'generic' => q(Парагвай вақти),
				'standard' => q(Парагвай стандарт вақти),
			},
		},
		'Peru' => {
			long => {
				'daylight' => q(Перу ёзги вақти),
				'generic' => q(Перу вақти),
				'standard' => q(Перу стандарт вақти),
			},
		},
		'Philippines' => {
			long => {
				'daylight' => q(Филиппин ёзги вақти),
				'generic' => q(Филиппин вақти),
				'standard' => q(Филиппин стандарт вақти),
			},
		},
		'Phoenix_Islands' => {
			long => {
				'standard' => q(Феникс ороллари вақти),
			},
		},
		'Pierre_Miquelon' => {
			long => {
				'daylight' => q(Сент-Пьер ва Микелон кундузги вақти),
				'generic' => q(Сент-Пьер ва Микелон вақти),
				'standard' => q(Сент-Пьер ва Микелон стандарт вақти),
			},
		},
		'Pitcairn' => {
			long => {
				'standard' => q(Питкерн вақти),
			},
		},
		'Ponape' => {
			long => {
				'standard' => q(Понапе вақти),
			},
		},
		'Reunion' => {
			long => {
				'standard' => q(Реюньон вақти),
			},
		},
		'Rothera' => {
			long => {
				'standard' => q(Ротера вақти),
			},
		},
		'Sakhalin' => {
			long => {
				'daylight' => q(Сахалин ёзги вақти),
				'generic' => q(Сахалин вақти),
				'standard' => q(Сахалин стандарт вақти),
			},
		},
		'Samoa' => {
			long => {
				'daylight' => q(Самоа кундузги вақти),
				'generic' => q(Самоа вақти),
				'standard' => q(Самоа стандарт вақти),
			},
		},
		'Seychelles' => {
			long => {
				'standard' => q(Сейшел ороллари вақти),
			},
		},
		'Singapore' => {
			long => {
				'standard' => q(Сингапур вақти),
			},
		},
		'Solomon' => {
			long => {
				'standard' => q(Соломон ороллари вақти),
			},
		},
		'South_Georgia' => {
			long => {
				'standard' => q(Жанубий Джорджия вақти),
			},
		},
		'Suriname' => {
			long => {
				'standard' => q(Суринам вақти),
			},
		},
		'Syowa' => {
			long => {
				'standard' => q(Сьова вақти),
			},
		},
		'Tahiti' => {
			long => {
				'standard' => q(Таити вақти),
			},
		},
		'Taipei' => {
			long => {
				'daylight' => q(Тайпей кундузги вақти),
				'generic' => q(Тайпей вақти),
				'standard' => q(Тайпей стандарт вақти),
			},
		},
		'Tajikistan' => {
			long => {
				'standard' => q(Тожикистон вақти),
			},
		},
		'Tokelau' => {
			long => {
				'standard' => q(Токелау вақти),
			},
		},
		'Tonga' => {
			long => {
				'daylight' => q(Тонга ёзги вақти),
				'generic' => q(Тонга вақти),
				'standard' => q(Тонга стандарт вақти),
			},
		},
		'Truk' => {
			long => {
				'standard' => q(Чуук вақти),
			},
		},
		'Turkmenistan' => {
			long => {
				'daylight' => q(Туркманистон ёзги вақти),
				'generic' => q(Туркманистон вақти),
				'standard' => q(Туркманистон стандарт вақти),
			},
		},
		'Tuvalu' => {
			long => {
				'standard' => q(Тувалу вақти),
			},
		},
		'Uruguay' => {
			long => {
				'daylight' => q(Уругвай ёзги вақти),
				'generic' => q(Уругвай вақти),
				'standard' => q(Уругвай стандарт вақти),
			},
		},
		'Uzbekistan' => {
			long => {
				'daylight' => q(Ўзбекистон ёзги вақти),
				'generic' => q(Ўзбекистон вақти),
				'standard' => q(Ўзбекистон стандарт вақти),
			},
		},
		'Vanuatu' => {
			long => {
				'daylight' => q(Вануату ёзги вақти),
				'generic' => q(Вануату вақти),
				'standard' => q(Вануату стандарт вақти),
			},
		},
		'Venezuela' => {
			long => {
				'standard' => q(Венесуэла вақти),
			},
		},
		'Vladivostok' => {
			long => {
				'daylight' => q(Владивосток ёзги вақти),
				'generic' => q(Владивосток вақти),
				'standard' => q(Владивосток стандарт вақти),
			},
		},
		'Volgograd' => {
			long => {
				'daylight' => q(Волгоград ёзги вақти),
				'generic' => q(Волгоград вақти),
				'standard' => q(Волгоград стандарт вақти),
			},
		},
		'Vostok' => {
			long => {
				'standard' => q(Восток вақти),
			},
		},
		'Wake' => {
			long => {
				'standard' => q(Уэйк ороли вақти),
			},
		},
		'Wallis' => {
			long => {
				'standard' => q(Уэллис ва Футуна вақти),
			},
		},
		'Yakutsk' => {
			long => {
				'daylight' => q(Якутск ёзги вақти),
				'generic' => q(Якутск вақти),
				'standard' => q(Якутск стандарт вақти),
			},
		},
		'Yekaterinburg' => {
			long => {
				'daylight' => q(Екатеринбург ёзги вақти),
				'generic' => q(Екатеринбург вақти),
				'standard' => q(Екатеринбург стандарт вақти),
			},
		},
	 } }
);
no Moo;

1;

# vim: tabstop=4
